@@ -19,5 +19,3 @@
 
 extern int read_proc(unsigned long int *prcs_run, unsigned long int *prcs_blked);
 extern void detect_consoles(void);
-extern void unraw_consoles(void);
-extern void raw_consoles(void);
